package com.doc.biz.controller;

import com.doc.biz.domain.DocDirUser;
import com.doc.biz.service.IDocDirUserService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 组织目录成员Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "组织目录成员")
@RestController
@RequestMapping("/biz/user")
public class DocDirUserController extends BaseController {
    @Resource
    private IDocDirUserService docDirUserService;

    /**
     * 查询组织目录成员列表
     */
    @ApiOperation("查询组织目录成员列表")
    //@PreAuthorize("@ss.hasPermi('biz:user:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocDirUser docDirUser) {
        startPage();
        List<DocDirUser> list = docDirUserService.selectDocDirUserList(docDirUser);
        return getDataTable(list);
    }

    /**
     * 导出组织目录成员列表
     */
    @ApiOperation("导出组织目录成员列表")
    //@PreAuthorize("@ss.hasPermi('biz:user:export')")
    @Log(title = "组织目录成员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocDirUser docDirUser) {
        List<DocDirUser> list = docDirUserService.selectDocDirUserList(docDirUser);
        ExcelUtil<DocDirUser> util = new ExcelUtil<DocDirUser>(DocDirUser.class);
        util.exportExcel(response, list, "组织目录成员数据");
    }

    /**
     * 获取组织目录成员详细信息
     */
    @ApiOperation("获取组织目录成员详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:user:query')")
    @GetMapping(value = "/{autoId}")
    public AjaxResult getInfo(@PathVariable("autoId") Long autoId) {
        return success(docDirUserService.selectDocDirUserByAutoId(autoId));
    }

    /**
     * 新增组织目录成员
     */
    @ApiOperation("新增组织目录成员")
    //@PreAuthorize("@ss.hasPermi('biz:user:add')")
    @Log(title = "组织目录成员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocDirUser docDirUser) {
        return toAjax(docDirUserService.insertDocDirUser(docDirUser));
    }

    /**
     * 修改组织目录成员
     */
    @ApiOperation("修改组织目录成员")
    //@PreAuthorize("@ss.hasPermi('biz:user:edit')")
    @Log(title = "组织目录成员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocDirUser docDirUser) {
        return toAjax(docDirUserService.updateDocDirUser(docDirUser));
    }

    /**
     * 删除组织目录成员
     */
    @ApiOperation("删除组织目录成员")
    //@PreAuthorize("@ss.hasPermi('biz:user:remove')")
    @Log(title = "组织目录成员", businessType = BusinessType.DELETE)
    @DeleteMapping("/{autoIds}")
    public AjaxResult remove(@PathVariable Long[] autoIds) {
        return toAjax(docDirUserService.deleteDocDirUserByAutoIds(autoIds));
    }
}
