package com.doc.biz.controller;

import com.doc.biz.domain.DocRecent;
import com.doc.biz.service.IDocRecentService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 最近文件Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "最近文件")
@RestController
@RequestMapping("/biz/recent")
public class DocRecentController extends BaseController {
    @Resource
    private IDocRecentService docRecentService;

    /**
     * 查询最近文件列表
     */
    @ApiOperation("查询最近文件列表")
    //@PreAuthorize("@ss.hasPermi('biz:recent:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocRecent docRecent) {
        startPage();
        List<DocRecent> list = docRecentService.selectDocRecentList(docRecent);
        return getDataTable(list);
    }

    /**
     * 导出最近文件列表
     */
    @ApiOperation("导出最近文件列表")
    //@PreAuthorize("@ss.hasPermi('biz:recent:export')")
    @Log(title = "最近文件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocRecent docRecent) {
        List<DocRecent> list = docRecentService.selectDocRecentList(docRecent);
        ExcelUtil<DocRecent> util = new ExcelUtil<DocRecent>(DocRecent.class);
        util.exportExcel(response, list, "最近文件数据");
    }

    /**
     * 获取最近文件详细信息
     */
    @ApiOperation("获取最近文件详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:recent:query')")
    @GetMapping(value = "/{recentId}")
    public AjaxResult getInfo(@PathVariable("recentId") Long recentId) {
        return success(docRecentService.selectDocRecentByRecentId(recentId));
    }

    /**
     * 新增最近文件
     */
    @ApiOperation("新增最近文件")
    //@PreAuthorize("@ss.hasPermi('biz:recent:add')")
    @Log(title = "最近文件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocRecent docRecent) {
        return toAjax(docRecentService.insertDocRecent(docRecent));
    }

    /**
     * 修改最近文件
     */
    @ApiOperation("修改最近文件")
    //@PreAuthorize("@ss.hasPermi('biz:recent:edit')")
    @Log(title = "最近文件", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocRecent docRecent) {
        return toAjax(docRecentService.updateDocRecent(docRecent));
    }

    /**
     * 删除最近文件
     */
    @ApiOperation("删除最近文件")
    //@PreAuthorize("@ss.hasPermi('biz:recent:remove')")
    @Log(title = "最近文件", businessType = BusinessType.DELETE)
    @DeleteMapping("/{recentIds}")
    public AjaxResult remove(@PathVariable Long[] recentIds) {
        return toAjax(docRecentService.deleteDocRecentByRecentIds(recentIds));
    }
}
