package com.doc.biz.controller;

import com.doc.biz.domain.DocSpaceExpansion;
import com.doc.biz.service.IDocSpaceExpansionService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 空间扩容管理Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "空间扩容管理")
@RestController
@RequestMapping("/biz/expansion")
public class DocSpaceExpansionController extends BaseController {
    @Resource
    private IDocSpaceExpansionService docSpaceExpansionService;

    /**
     * 查询空间扩容管理列表
     */
    @ApiOperation("查询空间扩容管理列表")
    //@PreAuthorize("@ss.hasPermi('biz:expansion:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocSpaceExpansion docSpaceExpansion) {
        startPage();
        List<DocSpaceExpansion> list = docSpaceExpansionService.selectDocSpaceExpansionList(docSpaceExpansion);
        return getDataTable(list);
    }

    /**
     * 导出空间扩容管理列表
     */
    @ApiOperation("导出空间扩容管理列表")
    //@PreAuthorize("@ss.hasPermi('biz:expansion:export')")
    @Log(title = "空间扩容管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocSpaceExpansion docSpaceExpansion) {
        List<DocSpaceExpansion> list = docSpaceExpansionService.selectDocSpaceExpansionList(docSpaceExpansion);
        ExcelUtil<DocSpaceExpansion> util = new ExcelUtil<DocSpaceExpansion>(DocSpaceExpansion.class);
        util.exportExcel(response, list, "空间扩容管理数据");
    }

    /**
     * 获取空间扩容管理详细信息
     */
    @ApiOperation("获取空间扩容管理详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:expansion:query')")
    @GetMapping(value = "/{autoId}")
    public AjaxResult getInfo(@PathVariable("autoId") Long autoId) {
        return success(docSpaceExpansionService.selectDocSpaceExpansionByAutoId(autoId));
    }

    /**
     * 新增空间扩容管理
     */
    @ApiOperation("新增空间扩容管理")
    //@PreAuthorize("@ss.hasPermi('biz:expansion:add')")
    @Log(title = "空间扩容管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocSpaceExpansion docSpaceExpansion) {
        return toAjax(docSpaceExpansionService.insertDocSpaceExpansion(docSpaceExpansion));
    }

    /**
     * 修改空间扩容管理
     */
    @ApiOperation("修改空间扩容管理")
    //@PreAuthorize("@ss.hasPermi('biz:expansion:edit')")
    @Log(title = "空间扩容管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocSpaceExpansion docSpaceExpansion) {
        return toAjax(docSpaceExpansionService.updateDocSpaceExpansion(docSpaceExpansion));
    }

    /**
     * 删除空间扩容管理
     */
    @ApiOperation("删除空间扩容管理")
    //@PreAuthorize("@ss.hasPermi('biz:expansion:remove')")
    @Log(title = "空间扩容管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{autoIds}")
    public AjaxResult remove(@PathVariable Long[] autoIds) {
        return toAjax(docSpaceExpansionService.deleteDocSpaceExpansionByAutoIds(autoIds));
    }
}
