package com.doc.biz.controller;

import com.doc.biz.domain.DocVersion;
import com.doc.biz.service.IDocVersionService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文档版本信息Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文档版本信息")
@RestController
@RequestMapping("/biz/version")
public class DocVersionController extends BaseController {
    @Resource
    private IDocVersionService docVersionService;

    /**
     * 查询文档版本信息列表
     */
    @ApiOperation("查询文档版本信息列表")
    //@PreAuthorize("@ss.hasPermi('biz:version:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocVersion docVersion) {
        startPage();
        List<DocVersion> list = docVersionService.selectDocVersionList(docVersion);
        return getDataTable(list);
    }

    /**
     * 导出文档版本信息列表
     */
    @ApiOperation("导出文档版本信息列表")
    //@PreAuthorize("@ss.hasPermi('biz:version:export')")
    @Log(title = "文档版本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocVersion docVersion) {
        List<DocVersion> list = docVersionService.selectDocVersionList(docVersion);
        ExcelUtil<DocVersion> util = new ExcelUtil<DocVersion>(DocVersion.class);
        util.exportExcel(response, list, "文档版本信息数据");
    }

    /**
     * 获取文档版本信息详细信息
     */
    @ApiOperation("获取文档版本信息详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:version:query')")
    @GetMapping(value = "/{versionId}")
    public AjaxResult getInfo(@PathVariable("versionId") Long versionId) {
        return success(docVersionService.selectDocVersionByVersionId(versionId));
    }

    /**
     * 新增文档版本信息
     */
    @ApiOperation("新增文档版本信息")
    //@PreAuthorize("@ss.hasPermi('biz:version:add')")
    @Log(title = "文档版本信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocVersion docVersion) {
        return toAjax(docVersionService.insertDocVersion(docVersion));
    }

    /**
     * 修改文档版本信息
     */
    @ApiOperation("修改文档版本信息")
    //@PreAuthorize("@ss.hasPermi('biz:version:edit')")
    @Log(title = "文档版本信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocVersion docVersion) {
        return toAjax(docVersionService.updateDocVersion(docVersion));
    }

    /**
     * 删除文档版本信息
     */
    @ApiOperation("删除文档版本信息")
    //@PreAuthorize("@ss.hasPermi('biz:version:remove')")
    @Log(title = "文档版本信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{versionIds}")
    public AjaxResult remove(@PathVariable Long[] versionIds) {
        return toAjax(docVersionService.deleteDocVersionByVersionIds(versionIds));
    }
}
