package com.doc.biz.service.impl;

import com.doc.biz.domain.DocRecent;
import com.doc.biz.mapper.DocRecentMapper;
import com.doc.biz.service.IDocRecentService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 最近文件Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocRecentServiceImpl implements IDocRecentService {
    @Resource
    private DocRecentMapper docRecentMapper;

    /**
     * 查询最近文件
     *
     * @param recentId 最近文件主键
     * @return 最近文件
     */
    @Override
    public DocRecent selectDocRecentByRecentId(Long recentId) {
        return docRecentMapper.selectDocRecentByRecentId(recentId);
    }

    /**
     * 查询最近文件列表
     *
     * @param docRecent 最近文件
     * @return 最近文件
     */
    @Override
    public List<DocRecent> selectDocRecentList(DocRecent docRecent) {
        return docRecentMapper.selectDocRecentList(docRecent);
    }

    /**
     * 新增最近文件
     *
     * @param docRecent 最近文件
     * @return 结果
     */
    @Override
    public int insertDocRecent(DocRecent docRecent) {
        docRecent.setCreateTime(DateUtils.getNowDate());
        return docRecentMapper.insertDocRecent(docRecent);
    }

    /**
     * 修改最近文件
     *
     * @param docRecent 最近文件
     * @return 结果
     */
    @Override
    public int updateDocRecent(DocRecent docRecent) {
        docRecent.setUpdateTime(DateUtils.getNowDate());
        return docRecentMapper.updateDocRecent(docRecent);
    }

    /**
     * 批量删除最近文件
     *
     * @param recentIds 需要删除的最近文件主键
     * @return 结果
     */
    @Override
    public int deleteDocRecentByRecentIds(Long[] recentIds) {
        return docRecentMapper.deleteDocRecentByRecentIds(recentIds);
    }

    /**
     * 删除最近文件信息
     *
     * @param recentId 最近文件主键
     * @return 结果
     */
    @Override
    public int deleteDocRecentByRecentId(Long recentId) {
        return docRecentMapper.deleteDocRecentByRecentId(recentId);
    }
}
