package com.doc.chat.service.impl;

import java.util.List;
import java.util.Map;

import com.doc.common.core.domain.entity.SysUser;
import com.doc.common.utils.DateUtils;
import com.doc.system.service.ISysUserService;
import org.springframework.stereotype.Service;
import com.doc.chat.mapper.ChatMsgMapper;
import com.doc.chat.domain.ChatMsg;
import com.doc.chat.service.IChatMsgService;

import javax.annotation.Resource;

/**
 * 聊天消息管理Service业务层处理
 *
 * @author wukai
 * @date 2023-08-24
 */
@Service
public class ChatMsgServiceImpl implements IChatMsgService {
    @Resource
    private ChatMsgMapper chatMsgMapper;
    @Resource
    private ISysUserService userService;

    /**
     * 查询聊天消息管理
     *
     * @param msgId 聊天消息管理主键
     * @return 聊天消息管理
     */
    @Override
    public ChatMsg selectChatMsgByMsgId(Long msgId) {
        return chatMsgMapper.selectChatMsgByMsgId(msgId);
    }

    /**
     * 查询聊天消息管理列表
     *
     * @param chatMsg 聊天消息管理
     * @return 聊天消息管理
     */
    @Override
    public List<ChatMsg> selectChatMsgList(ChatMsg chatMsg) {
        return chatMsgMapper.selectChatMsgList(chatMsg);
    }

    /**
     * 新增聊天消息管理
     *
     * @param chatMsg 聊天消息管理
     * @return 结果
     */
    @Override
    public int insertChatMsg(ChatMsg chatMsg) {
        String idIndex = getIdIndex(chatMsg.getFromId(), chatMsg.getToId());
        chatMsg.setIdIndex(idIndex);
        chatMsg.setCreateTime(DateUtils.getNowDate());
        return chatMsgMapper.insertChatMsg(chatMsg);
    }

    private String getIdIndex(Long fromId, Long toId) {
        String idIndex = fromId + "" + toId;
        if (fromId > toId) {
            idIndex = toId + "" + fromId;
        }
        return idIndex;
    }

    /**
     * 修改聊天消息管理
     *
     * @param chatMsg 聊天消息管理
     * @return 结果
     */
    @Override
    public int updateChatMsg(ChatMsg chatMsg) {
        return chatMsgMapper.updateChatMsg(chatMsg);
    }

    /**
     * 批量删除聊天消息管理
     *
     * @param msgIds 需要删除的聊天消息管理主键
     * @return 结果
     */
    @Override
    public int deleteChatMsgByMsgIds(Long[] msgIds) {
        return chatMsgMapper.deleteChatMsgByMsgIds(msgIds);
    }

    /**
     * 删除聊天消息管理信息
     *
     * @param msgId 聊天消息管理主键
     * @return 结果
     */
    @Override
    public int deleteChatMsgByMsgId(Long msgId) {
        return chatMsgMapper.deleteChatMsgByMsgId(msgId);
    }

    /**
     * 获取聊天记录
     *
     * @param fromId 当前用户ID
     * @param toId   接收用户ID
     * @return 聊天记录列表
     */
    @Override
    public List<ChatMsg> selectRecordList(Long fromId, Long toId) {
        List<ChatMsg> msgList = chatMsgMapper.selectRecordList(getIdIndex(fromId, toId));
        setUserInfo(msgList);
        return msgList;
    }

    /**
     * 查询好友列表
     *
     * @param userId 当前用户ID
     * @return 好友列表
     */
    @Override
    public List<ChatMsg> selectFriendList(Long userId) {
        List<ChatMsg> msgList = chatMsgMapper.selectFriendList(userId);
        setUserInfo(msgList);
        return msgList;
    }

    /**
     * 设置用户信息
     *
     * @param msgList 消息列表
     */
    private void setUserInfo(List<ChatMsg> msgList) {
        Map<Long, SysUser> userMap = userService.selectAllUser();
        for (ChatMsg msg : msgList) {
            SysUser fromUser = userMap.get(msg.getFromId());
            SysUser toUser = userMap.get(msg.getToId());
            msg.setFromName(fromUser.getNickName());
            msg.setFromAvatar(fromUser.getAvatar());

            msg.setToName(toUser.getNickName());
            msg.setToAvatar(toUser.getAvatar());
        }
    }

}
